package br.usp.ime.forum;

import java.io.IOException;
import java.util.Arrays;
import java.util.List;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.RequestDispatcher;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

import br.usp.ime.forum.model.Privilegio;
import br.usp.ime.forum.model.Usuario;

public class ControleDeAcessoFilter implements Filter {

	private List<String> recursosLivres;
	private List<String> recursosSomenteAdministradores;

	public ControleDeAcessoFilter() {
	}

	public void destroy() {
	}

	public void doFilter(ServletRequest request, ServletResponse response,
			FilterChain chain) throws IOException, ServletException {
		HttpServletRequest httpRequest = (HttpServletRequest) request;
		String recursoRequisitado = httpRequest.getServletPath();
		String[] recursoRequisitadoSplit = recursoRequisitado.split("/");
		recursoRequisitado = recursoRequisitadoSplit[recursoRequisitadoSplit.length - 1];
		if (!recursosLivres.contains(recursoRequisitado)) {
			HttpSession session = httpRequest.getSession();
			Usuario usuario = (Usuario) session.getAttribute("usuario");
			if (usuario == null) {
				setMensagem("Sesso expirada!", request);
				depachaParaLogin(httpRequest, response);
				return;
			}
			if (recursosSomenteAdministradores.contains(recursoRequisitado)
					&& !(usuario.getPrivilegio()
							.equals(Privilegio.ADMINISTRADOR))) {
				setMensagem("Voc no possui autorizao para fazer isto!",
						request);
				depachaParaLogin(httpRequest, response);
				return;
			}
		}
		chain.doFilter(request, response);

	}

	private void depachaParaLogin(HttpServletRequest request,
			ServletResponse response) throws ServletException, IOException {
		RequestDispatcher dispatcher = request
				.getRequestDispatcher("/login.jsp");
		dispatcher.forward(request, response);
	}

	private void setMensagem(String mensagem, ServletRequest request) {
		request.setAttribute("mensagem", mensagem);
	}

	public void init(FilterConfig fConfig) throws ServletException {
		String recursosLivresString = fConfig
				.getInitParameter("recursosLivresDeControleDeAcesso");
		String[] recursosLivresSplit = recursosLivresString.split(",");
		recursosLivres = Arrays.asList(recursosLivresSplit);

		String recursosAdministradoresString = fConfig
				.getInitParameter("recursosSomenteAdministradores");
		String[] recursosAdministradoresSplit = recursosAdministradoresString
				.split(",");
		recursosSomenteAdministradores = Arrays
				.asList(recursosAdministradoresSplit);
	}

}
