package br.usp.ime.forum.business;

import java.util.List;

import br.usp.ime.forum.dao.UsuarioDAO;
import br.usp.ime.forum.ex.SenhaEConfirmacaoDiferentesException;
import br.usp.ime.forum.ex.UsuarioNaoAutenticadoException;
import br.usp.ime.forum.ex.UsuarioNaoAutorizadoException;
import br.usp.ime.forum.model.Privilegio;
import br.usp.ime.forum.model.Usuario;

public class UsuarioBusiness {

	private UsuarioDAO usuarioDAO = UsuarioDAO.getInstance();
	
	public void cadastraUsuario(String nome, String email, String nomeDeUsuario,
			String senha, String confirmacaoSenha) throws SenhaEConfirmacaoDiferentesException {
		if(senha == null || !senha.equals(confirmacaoSenha)){
			throw new SenhaEConfirmacaoDiferentesException();
		}
		Usuario usuario = new Usuario(nome,email,nomeDeUsuario,senha);
		usuarioDAO.cadastraUsuario(usuario);
		
	}

	public Usuario logar(String nomeDeUsuario, String senha) throws UsuarioNaoAutenticadoException, UsuarioNaoAutorizadoException {
		
		Usuario usuario = usuarioDAO.findUsuarioPorNomeDeUsuarioESenha(nomeDeUsuario,senha);
		
		if(usuario == null){
			throw new UsuarioNaoAutenticadoException();
		}if(!usuario.isAutorizado()){
			throw new UsuarioNaoAutorizadoException();
		}
		return usuario;
	}

	public List<Usuario> getUsuariosNaoAutorizados() {
		
		List<Usuario> usuarios = usuarioDAO.findNaoAutorizados();
		return usuarios;
	}

	public void autorizaUsuario(Long idUsuario) {
		UsuarioDAO.getInstance().autorizaUsuario(idUsuario);
	}

	public List<Usuario> getTodosOsUsuarios() {
		
		List<Usuario> usuarios = usuarioDAO.findTodos();
		return usuarios;
	}

	public Usuario getUsuarioPorId(Long idUsuario) {
		
		Usuario usuario = usuarioDAO.findById(idUsuario);
		return usuario;
	}

	public void alteraPrivilegioUsuario(Long idUsuario, Privilegio privilegio) {
		Usuario usuarioAnterior = getUsuarioPorId(idUsuario);
		Usuario usuarioNovo = usuarioDAO.clone(usuarioAnterior);
		usuarioNovo.setPrivilegio(privilegio);		
		usuarioDAO.altera(usuarioAnterior,usuarioNovo);
	}

}
